% This script calculates the losses due to spherical aberrations based
% on T1500326 written by Hiro Yamamoto together with functions used in 
% this script. It does not use the paraxial-approximation.

% Antonio Perreca 13 Aug 20155
% -----------------------------------------------------------------------

n = 1.45; th = 0.000; k=2*pi/1.064e-6;

tele(1).Ropt = -0.0498;
tele(1).Rin = 6.746;
tele(1).win = 638.7e-6;
tele(1).dist = 0.05;

tele(2).Ropt = 0.0258;
tele(2).Rin = -0.061;
tele(2).win = 350.3e-6;
tele(2).dist = 0.2809;

tele(3).Ropt = 0.0522;
tele(3).Rin = 0.623;
tele(3).win = 557e-6;
tele(3).dist = 0.05;

tele(4).Ropt = -0.0610;
tele(4).Rin = 0.146;
tele(4).win = 846e-6;
tele(4).dist = 0.9991;

fprintf(1, 'n = %g, lens th = %g =================\n', n, th );
for ilens = 1 : 4
    Labr = 5/256*(n-1)^2*k^2*tele(ilens).win^8/tele(ilens).Ropt^6;
    [Cs, Ps, wz] = modeLoss( tele(ilens).Ropt, tele(ilens).Rin, tele(ilens).win, tele(ilens).dist, n, th, 1 );
    [Cp, Pp] = modeLoss( tele(ilens).Ropt, tele(ilens).Rin, tele(ilens).win, tele(ilens).dist, n, th, 2 );
    fprintf(1, 'lens %d : Labr (eq 4.4) = %g, win = %g, wout = %g   ---- \n', ilens, Labr, tele(ilens).win, wz );
    fprintf(1, 'spherical : 00 mode loss = %g, dPwr = %g\n', 1-abs(Cs)^2, 1-Ps);
    fprintf(1, 'parabolic : 00 mode loss = %g, dPwr = %g\n', 1-abs(Cp)^2, 1-Pp);
end

